@@ -30,7 +30,7 @@ project = u'osc-placement'
 copyright = u'2016, OpenStack Foundation'
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -46,5 +46,18 @@ autoprogram_cliff_ignored = [
     '--print-empty', '--prefix', '--noindent', '--quote']
 
 # openstackdocstheme options
-repository_name = 'openstack/osc-placement'
-use_storyboard = True
+openstackdocs_repo_name = 'openstack/osc-placement'
+openstackdocs_pdf_link = True
+openstackdocs_auto_name = False
+openstackdocs_use_storyboard = True
+
+# -- Options for LaTeX output -------------------------------------------------
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass
+# [howto/manual]).
+latex_use_xindy = False
+latex_documents = [
+    ('index', 'doc-osc-placement.tex', u'osc-placement Documentation',
+     u'OpenStack Foundation', 'manual'),
+]
